@@ -6,10 +6,12 @@ function(mast, v.set, dir.set, num.sectors=12, alpha=NULL, digits=3, print=TRUE)
 	if(attr(mast, "call")$func!="createMast") stop(paste(substitute(mast), "is no mast object"))
 	num.sets <- length(mast$sets)
 	if(missing(v.set)) stop("Please choose one or two sets in 'v.set'\n")
-	if(any(!is.numeric(v.set)==TRUE)) stop("'v.set' must be numeric\n")
+	if(!is.numeric(v.set)) if(!(length(v.set)==1 && any(v.set=="all"))) v.set <- match(v.set, names(mast$sets))
+	if(any(is.na(v.set))) stop("'v.set' not found\n")
 	if(any(v.set<=0) || any(v.set>num.sets)) stop("'v.set' not found\n")
 	for(i in 1:length(v.set)) if(is.null(mast$sets[[v.set[i]]]$data$v.avg)) stop(paste("Set", v.set[i], "does not contain average wind speed data\n"))
-	if(length(dir.set)>1 || !is.numeric(dir.set)) stop("'dir.set' must be one numeric value\n")
+	if(!is.numeric(dir.set)) dir.set <- match(dir.set, names(mast$sets))
+	if(is.na(dir.set)) stop("'dir.set' not found\n")
 	if(dir.set<=0 || dir.set>num.sets) stop("'dir.set' not found\n")
 	if(is.null(mast$sets[[dir.set]]$data$dir.avg)) stop(paste("'dir.set' does not contain average wind direction data\n"))
 	if(!is.numeric(num.sectors)) stop("'num.sectors' must be numeric\n")
